==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebDisplayDensityBaseElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDescriptionMetadata } from "./WebDensityChangedEventArgsDescriptionMetadata";
import { WebDisplayDensityBaseElementDescription } from "./WebDisplayDensityBaseElementDescription";
/**
 * @hidden
 */
export let WebDisplayDensityBaseElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDisplayDensityBaseElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebDisplayDensityBaseElementDescriptionMetadata.a == null) {
                WebDisplayDensityBaseElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDisplayDensityBaseElementDescriptionMetadata.c(WebDisplayDensityBaseElementDescriptionMetadata.a);
            }
            if (a.j(WebDisplayDensityBaseElementDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDisplayDensityBaseElementDescriptionMetadata.a);
            WebDensityChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DisplayDensityBaseElement");
            a.item("__tagNameWC", "String:igc-display-density-base");
            a.item("DisplayDensity", "ExportedType:string:DisplayDensity");
            a.item("DisplayDensity@names", "Comfortable;Cosy;Compact");
            a.item("OnDensityChangedRef", "EventRef::onDensityChanged:customEvent");
        }
        static d(a) {
            WebDisplayDensityBaseElementDescriptionMetadata.b(a);
            a.aa("WebDisplayDensityBaseElement", () => new WebDisplayDensityBaseElementDescription());
            a.z("WebDisplayDensityBaseElement", WebDisplayDensityBaseElementDescriptionMetadata.a);
        }
    }
    WebDisplayDensityBaseElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDisplayDensityBaseElementDescriptionMetadata, 'WebDisplayDensityBaseElementDescriptionMetadata');
    WebDisplayDensityBaseElementDescriptionMetadata.a = null;
    return WebDisplayDensityBaseElementDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDisplayDensityBaseElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDescriptionMetadata } from "./WebDensityChangedEventArgsDescriptionMetadata";
import { WebDisplayDensityBaseElementDescription } from "./WebDisplayDensityBaseElementDescription";
/**
 * @hidden
 */
export let WebDisplayDensityBaseElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDisplayDensityBaseElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebDisplayDensityBaseElementDescriptionMetadata.a == null) {
                WebDisplayDensityBaseElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDisplayDensityBaseElementDescriptionMetadata.c(WebDisplayDensityBaseElementDescriptionMetadata.a);
            }
            if (a.k(WebDisplayDensityBaseElementDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDisplayDensityBaseElementDescriptionMetadata.a);
            WebDensityChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DisplayDensityBaseElement");
            a.item("__tagNameWC", "String:igc-display-density-base");
            a.item("DisplayDensity", "ExportedType:string:DisplayDensity");
            a.item("DisplayDensity@stringUnion", "WebComponents;React");
            a.item("DisplayDensity@names", "Comfortable;Cosy;Compact");
            a.item("OnDensityChangedRef", "EventRef::onDensityChanged:customEvent");
        }
        static d(a) {
            WebDisplayDensityBaseElementDescriptionMetadata.b(a);
            a.ac("WebDisplayDensityBaseElement", () => new WebDisplayDensityBaseElementDescription());
            a.ab("WebDisplayDensityBaseElement", WebDisplayDensityBaseElementDescriptionMetadata.a);
        }
    }
    WebDisplayDensityBaseElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDisplayDensityBaseElementDescriptionMetadata, 'WebDisplayDensityBaseElementDescriptionMetadata');
    WebDisplayDensityBaseElementDescriptionMetadata.a = null;
    return WebDisplayDensityBaseElementDescriptionMetadata;
})();
